list(
  rd_family_title = list(
    basic = "Basic functions",
    centralities = "Centrality measure functions",
    communities = "Community detection functions",
    cliques = "Clique-related functions",
    comparison = "Model comparison functions",
    validation = "Validation functions",
    clusters = "Cluster-related functions",
    helpers = "Helper functions",
    datasets = "Datasets"
  )
)
