% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/plot.R
\name{plot_compare.group_tna}
\alias{plot_compare.group_tna}
\title{Plot the Difference Network Between Two Groups}
\usage{
\method{plot_compare}{group_tna}(x, i = NULL, j = NULL, ...)
}
\arguments{
\item{x}{A \code{group_tna} object.}

\item{i}{An \code{integer} index or the name of the principal cluster as a
\code{character} string. When \code{NULL}, defaults are chosen automatically (see
\code{\link[cograph:plot_compare]{cograph::plot_compare()}}).}

\item{j}{An \code{integer} index or the name of the secondary cluster as a
\code{character} string. When \code{NULL}, defaults are chosen automatically (see
\code{\link[cograph:plot_compare]{cograph::plot_compare()}}).}

\item{...}{Additional arguments passed to \code{\link[cograph:plot_compare]{cograph::plot_compare()}}.}
}
\value{
A \code{cograph_network} object displaying the difference network between
the two clusters
}
\description{
Plot the Difference Network Between Two Groups
}
\examples{
model <- group_model(engagement_mmm)
plot_compare(model)

}
\seealso{
Model comparison functions
\code{\link{compare}()},
\code{\link{compare.group_tna}()},
\code{\link{compare_sequences}()},
\code{\link{plot.tna_comparison}()},
\code{\link{plot.tna_sequence_comparison}()},
\code{\link{plot_compare}()},
\code{\link{print.tna_comparison}()},
\code{\link{print.tna_sequence_comparison}()}
}
\concept{comparison}
