% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/simulate.R
\name{simulate}
\alias{simulate}
\title{Simulate Method (Re-export of \link[stats:simulate]{stats::simulate})}
\usage{
simulate(object, nsim = 1, seed = NULL, ...)
}
\arguments{
\item{object}{A statistical model object. The \code{tna} package provides
methods for objects of class \code{tna} and \code{group_tna}.}

\item{nsim}{An \code{integer} giving the number of sequences to simulate.}

\item{seed}{An \code{integer} random seed for reproducibility, or \code{NULL}.}

\item{...}{Further arguments passed to the dispatched method.}
}
\value{
The value returned by the dispatched method (a \code{data.frame} of
simulated sequences for \code{tna} and \code{group_tna} objects). See the
method-specific help pages for details.
}
\description{
The \code{\link[stats:simulate]{stats::simulate()}} generic is re-exported so that the
\code{simulate.tna()} and \code{simulate.group_tna()} methods provided by this
package are dispatched correctly when the user only loads \code{tna}.
See the method-specific help pages for argument and return details.
}
\examples{
model <- tna(group_regulation)
sim <- simulate(model, nsim = 5, max_len = 10)
}
