% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/random.R
\name{list_random_state_pools}
\alias{list_random_state_pools}
\title{List Built-in Label Pools for \code{\link[=random_tna]{random_tna()}}}
\usage{
list_random_state_pools()
}
\value{
A named \code{integer} vector mapping pool names to pool sizes.
}
\description{
Return the names of the curated state-label pools available to
\code{random_tna()} and \code{random_group_tna()}, with their sizes.
}
\examples{
list_random_state_pools()

}
\seealso{
Other data: 
\code{\link{import_data}()},
\code{\link{import_onehot}()},
\code{\link{prepare_data}()},
\code{\link{print.tna_data}()},
\code{\link{random_group_tna}()},
\code{\link{random_tna}()},
\code{\link{random_tna_mmm}()},
\code{\link{simulate.group_tna}()},
\code{\link{simulate.tna}()}
}
\concept{data}
